==> savane-1.1.tar.gz: savane-1.1/frontend/php/include/trackers_run/download.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: download.php,v 1.10 2005/06/30 17:19:36 toddy Exp $
#
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
#  Copyright 2002-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
#
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


$sql="SELECT description,file,filename,filesize,filetype FROM ".ARTIFACT."_file WHERE bug_file_id='$item_file_id' AND bug_id ='$item_id'";
$result=db_query($sql);

if ($result && db_numrows($result) > 0) 
{

  if (db_result($result,0,'filesize') == 0) 
    {

      exit_error('Error',_('nothing in here - File has a null size'));

    } 
  else 
    {
	
      # Download the patch with the correct filetype
      header('Content-Type: '.db_result($result,0,'filetype'));
      header('Content-Length: '.db_result($result,0,'filesize'));
      header('Content-Disposition: filename='.db_result($result,0,'filename'));
      header('Content-Description: '. db_result($result,0,'description'));

      echo db_result($result,0,'file');

    }

} 
else
{
  exit_error('Error',_("Couldn't find attached file ")."(id #$bug_file_id)");
}

?>

==> savane-1.3+2.tar.gz: savane-1.3+2/frontend/php/include/trackers_run/download.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: download.php 5187 2005-12-01 16:22:29Z yeupou $
#
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
#  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
#
#
# The Savane project is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# The Savane project is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the Savane project; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


if (isset($item_file_id)) 
{
  $file_id = $item_file_id;
}
#$file_id = safeinput($file_id);

# check if the provided file_id is a valid numerical id
if (!$file_id || !ctype_digit($file_id))
{
  exit_missing_param();
}

$sql="SELECT description,file,filename,filesize,filetype FROM trackers_file WHERE file_id='$file_id' LIMIT 1";
$result=db_query($sql);

if ($result && db_numrows($result) > 0) 
{

  if (db_result($result,0,'filesize') == 0) 
    {

      exit_error('Error',_('nothing in here - File has a null size'));

    } 
  else 
    {
	
      # Download the patch with the correct filetype
      header('Content-Type: '.db_result($result,0,'filetype'));
      header('Content-Length: '.db_result($result,0,'filesize'));
      header('Content-Disposition: filename='.db_result($result,0,'filename'));
      header('Content-Description: '. db_result($result,0,'description'));

      print db_result($result,0,'file');

    }

} 
else
{
  exit_error(_('Error'),_("Couldn't find attached file ")."(file #$file_id)");
}

?>
